@@ -2,9 +2,12 @@
 #include <cln/io.h>
 #include <cln/integer.h>
 #include <cln/modinteger.h>
-#include <stdlib.h>
-#include <string.h>
+#include <cstdlib>
+#include <cstring>
 #include <cln/timing.h>
+using namespace cln;
+#include <iostream>
+using namespace std;
 
 int main (int argc, char * argv[])
 {
